NativeMenu

Struct NativeMenu 

pub struct NativeMenu { /* private fields */ }
Godot class NativeMenu.

Inherits Object.

Related symbols:

  • native_menu: sidecar module with related enum/flag types

See also Godot docs for NativeMenu.

Singleton

This class is a singleton. You can get the one instance using Singleton::singleton().

Final class

This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.

Implementations

Source

impl NativeMenu

pub fn has_feature(&self, feature: Feature) -> bool

pub fn has_system_menu(&self, menu_id: SystemMenus) -> bool

pub fn get_system_menu(&self, menu_id: SystemMenus) -> Rid

pub fn get_system_menu_name(&self, menu_id: SystemMenus) -> GString

pub fn create_menu(&mut self) -> Rid

pub fn has_menu(&self, rid: Rid) -> bool

pub fn free_menu(&mut self, rid: Rid)

pub fn get_size(&self, rid: Rid) -> Vector2

pub fn popup(&mut self, rid: Rid, position: Vector2i)

pub fn set_interface_direction(&mut self, rid: Rid, is_rtl: bool)

pub fn set_popup_open_callback(&mut self, rid: Rid, callback: &Callable)

pub fn get_popup_open_callback(&self, rid: Rid) -> Callable

pub fn set_popup_close_callback(&mut self, rid: Rid, callback: &Callable)

pub fn get_popup_close_callback(&self, rid: Rid) -> Callable

pub fn set_minimum_width(&mut self, rid: Rid, width: f32)

pub fn get_minimum_width(&self, rid: Rid) -> f32

pub fn is_opened(&self, rid: Rid) -> bool

pub fn add_submenu_item( &mut self, rid: Rid, label: impl AsArg<GString>, submenu_rid: Rid, ) -> i32

To set the default parameters, use Self::add_submenu_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_submenu_item_ex<'a>( &'a mut self, rid: Rid, label: impl AsArg<GString> + 'a, submenu_rid: Rid, ) -> ExAddSubmenuItem<'a>

pub fn add_item(&mut self, rid: Rid, label: impl AsArg<GString>) -> i32

To set the default parameters, use Self::add_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_item_ex<'a>( &'a mut self, rid: Rid, label: impl AsArg<GString> + 'a, ) -> ExAddItem<'a>

pub fn add_check_item(&mut self, rid: Rid, label: impl AsArg<GString>) -> i32

To set the default parameters, use Self::add_check_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_check_item_ex<'a>( &'a mut self, rid: Rid, label: impl AsArg<GString> + 'a, ) -> ExAddCheckItem<'a>

pub fn add_icon_item( &mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>>, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use Self::add_icon_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_icon_item_ex<'a>( &'a mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>> + 'a, label: impl AsArg<GString> + 'a, ) -> ExAddIconItem<'a>

pub fn add_icon_check_item( &mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>>, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use Self::add_icon_check_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_icon_check_item_ex<'a>( &'a mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>> + 'a, label: impl AsArg<GString> + 'a, ) -> ExAddIconCheckItem<'a>

pub fn add_radio_check_item( &mut self, rid: Rid, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use Self::add_radio_check_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_radio_check_item_ex<'a>( &'a mut self, rid: Rid, label: impl AsArg<GString> + 'a, ) -> ExAddRadioCheckItem<'a>

pub fn add_icon_radio_check_item( &mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>>, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use Self::add_icon_radio_check_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_icon_radio_check_item_ex<'a>( &'a mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>> + 'a, label: impl AsArg<GString> + 'a, ) -> ExAddIconRadioCheckItem<'a>

pub fn add_multistate_item( &mut self, rid: Rid, label: impl AsArg<GString>, max_states: i32, default_state: i32, ) -> i32

To set the default parameters, use Self::add_multistate_item_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_multistate_item_ex<'a>( &'a mut self, rid: Rid, label: impl AsArg<GString> + 'a, max_states: i32, default_state: i32, ) -> ExAddMultistateItem<'a>

pub fn add_separator(&mut self, rid: Rid) -> i32

To set the default parameters, use Self::add_separator_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_separator_ex<'a>(&'a mut self, rid: Rid) -> ExAddSeparator<'a>

pub fn find_item_index_with_text( &self, rid: Rid, text: impl AsArg<GString>, ) -> i32

pub fn find_item_index_with_tag(&self, rid: Rid, tag: &Variant) -> i32

pub fn find_item_index_with_submenu(&self, rid: Rid, submenu_rid: Rid) -> i32

pub fn is_item_checked(&self, rid: Rid, idx: i32) -> bool

pub fn is_item_checkable(&self, rid: Rid, idx: i32) -> bool

pub fn is_item_radio_checkable(&self, rid: Rid, idx: i32) -> bool

pub fn get_item_callback(&self, rid: Rid, idx: i32) -> Callable

pub fn get_item_key_callback(&self, rid: Rid, idx: i32) -> Callable

pub fn get_item_tag(&self, rid: Rid, idx: i32) -> Variant

pub fn get_item_text(&self, rid: Rid, idx: i32) -> GString

pub fn get_item_submenu(&self, rid: Rid, idx: i32) -> Rid

pub fn get_item_accelerator(&self, rid: Rid, idx: i32) -> Key

pub fn is_item_disabled(&self, rid: Rid, idx: i32) -> bool

pub fn is_item_hidden(&self, rid: Rid, idx: i32) -> bool

pub fn get_item_tooltip(&self, rid: Rid, idx: i32) -> GString

pub fn get_item_state(&self, rid: Rid, idx: i32) -> i32

pub fn get_item_max_states(&self, rid: Rid, idx: i32) -> i32

pub fn get_item_icon(&self, rid: Rid, idx: i32) -> Option<Gd<Texture2D>>

pub fn get_item_indentation_level(&self, rid: Rid, idx: i32) -> i32

pub fn set_item_checked(&mut self, rid: Rid, idx: i32, checked: bool)

pub fn set_item_checkable(&mut self, rid: Rid, idx: i32, checkable: bool)

pub fn set_item_radio_checkable(&mut self, rid: Rid, idx: i32, checkable: bool)

pub fn set_item_callback(&mut self, rid: Rid, idx: i32, callback: &Callable)

pub fn set_item_hover_callbacks( &mut self, rid: Rid, idx: i32, callback: &Callable, )

pub fn set_item_key_callback( &mut self, rid: Rid, idx: i32, key_callback: &Callable, )

pub fn set_item_tag(&mut self, rid: Rid, idx: i32, tag: &Variant)

pub fn set_item_text(&mut self, rid: Rid, idx: i32, text: impl AsArg<GString>)

pub fn set_item_submenu(&mut self, rid: Rid, idx: i32, submenu_rid: Rid)

pub fn set_item_accelerator(&mut self, rid: Rid, idx: i32, keycode: Key)

pub fn set_item_disabled(&mut self, rid: Rid, idx: i32, disabled: bool)

pub fn set_item_hidden(&mut self, rid: Rid, idx: i32, hidden: bool)

pub fn set_item_tooltip( &mut self, rid: Rid, idx: i32, tooltip: impl AsArg<GString>, )

pub fn set_item_state(&mut self, rid: Rid, idx: i32, state: i32)

pub fn set_item_max_states(&mut self, rid: Rid, idx: i32, max_states: i32)

pub fn set_item_icon( &mut self, rid: Rid, idx: i32, icon: impl AsArg<Option<Gd<Texture2D>>>, )

pub fn set_item_indentation_level(&mut self, rid: Rid, idx: i32, level: i32)

pub fn get_item_count(&self, rid: Rid) -> i32

pub fn is_system_menu(&self, rid: Rid) -> bool

pub fn remove_item(&mut self, rid: Rid, idx: i32)

pub fn clear(&mut self, rid: Rid)

Methods from Deref<Target = Object>

pub fn get_script(&self) -> Option<Gd<Script>>

pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)

pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error

pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error

pub fn get_class(&self) -> GString

pub fn is_class(&self, class: impl AsArg<GString>) -> bool

pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)

pub fn get(&self, property: impl AsArg<StringName>) -> Variant

pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )

pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant

pub fn get_property_list(&self) -> Array<Dictionary>

pub fn get_method_list(&self) -> Array<Dictionary>

pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool

pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant

pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)

pub fn remove_meta(&mut self, name: impl AsArg<StringName>)

pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant

To set the default parameters, use Self::get_meta_ex and its builder methods. See the book for detailed usage instructions.

pub fn get_meta_ex<'a>( &'a self, name: impl AsArg<StringName> + 'a, ) -> ExGetMeta<'a>

pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool

pub fn get_meta_list(&self) -> Array<StringName>

pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)

To set the default parameters, use Self::add_user_signal_ex and its builder methods. See the book for detailed usage instructions.

pub fn add_user_signal_ex<'a>( &'a mut self, signal: impl AsArg<GString> + 'a, ) -> ExAddUserSignal<'a>

pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool

pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)

pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )

pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &Array<Variant>, ) -> Variant

pub fn has_method(&self, method: impl AsArg<StringName>) -> bool

pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32

pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool

pub fn get_signal_list(&self) -> Array<Dictionary>

pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary>

pub fn get_incoming_connections(&self) -> Array<Dictionary>

pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )

pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool

pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool

pub fn set_block_signals(&mut self, enable: bool)

pub fn is_blocking_signals(&self) -> bool

pub fn notify_property_list_changed(&mut self)

pub fn set_message_translation(&mut self, enable: bool)

pub fn can_translate_messages(&self) -> bool

pub fn tr(&self, message: impl AsArg<StringName>) -> GString

To set the default parameters, use Self::tr_ex and its builder methods. See the book for detailed usage instructions.

pub fn tr_ex<'a>(&'a self, message: impl AsArg<StringName> + 'a) -> ExTr<'a>

pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString

To set the default parameters, use Self::tr_n_ex and its builder methods. See the book for detailed usage instructions.

pub fn tr_n_ex<'a>( &'a self, message: impl AsArg<StringName> + 'a, plural_message: impl AsArg<StringName> + 'a, n: i32, ) -> ExTrN<'a>

pub fn get_translation_domain(&self) -> StringName

pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)

pub fn is_queued_for_deletion(&self) -> bool

pub fn cancel_free(&mut self)

pub fn notify(&mut self, what: ObjectNotification)

⚠️ Sends a Godot notification to all classes inherited by the object.

Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().

Starts from the highest ancestor (the Object class) and goes down the hierarchy. See also Godot docs for Object::notification().

Panics

If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must be exclusive.

pub fn notify_reversed(&mut self, what: ObjectNotification)

⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.

See docs of that method, including the panics.