pub struct Node { /* private fields */ }Expand description
Godot class Node.
Inherits Object.
Related symbols:
node: sidecar module with related enum/flag typesINode: virtual methodsSignalsOfNode: signal collectionNodeNotification: notification type
See also Godot docs for Node.
Construction
This class is manually managed. You can create a new instance using Node::new_alloc().
Do not forget to call free() or hand over ownership to Godot.
Godot docs
Nodes are Godot’s building blocks. They can be assigned as the child of another node, resulting in a tree arrangement. A given node can contain any number of nodes as children with the requirement that all siblings (direct children of a node) should have unique names.
A tree of nodes is called a scene. Scenes can be saved to the disk and then instantiated into other scenes. This allows for very high flexibility in the architecture and data model of Godot projects.
Scene tree: The SceneTree contains the active tree of nodes. When a node is added to the scene tree, it receives the [constant NOTIFICATION_ENTER_TREE] notification and its enter_tree callback is triggered. Child nodes are always added after their parent node, i.e. the enter_tree callback of a parent node will be triggered before its child’s.
Once all nodes have been added in the scene tree, they receive the [constant NOTIFICATION_READY] notification and their respective ready callbacks are triggered. For groups of nodes, the ready callback is called in reverse order, starting with the children and moving up to the parent nodes.
This means that when adding a node to the scene tree, the following order will be used for the callbacks: enter_tree of the parent, enter_tree of the children, ready of the children and finally ready of the parent (recursively for the entire scene tree).
Processing: Nodes can override the “process” state, so that they receive a callback on each frame requesting them to process (do something). Normal processing (callback process, toggled with set_process) happens as fast as possible and is dependent on the frame rate, so the processing time delta (in seconds) is passed as an argument. Physics processing (callback physics_process, toggled with set_physics_process) happens a fixed number of times per second (60 by default) and is useful for code related to the physics engine.
Nodes can also process input events. When present, the input function will be called for each input that the program receives. In many cases, this can be overkill (unless used for simple projects), and the unhandled_input function might be preferred; it is called when the input event was not handled by anyone else (typically, GUI Control nodes), ensuring that the node only receives the events that were meant for it.
To keep track of the scene hierarchy (especially when instantiating scenes into other scenes), an “owner” can be set for the node with the [member owner] property. This keeps track of who instantiated what. This is mostly useful when writing editors and tools, though.
Finally, when a node is freed with free or queue_free, it will also free all its children.
Groups: Nodes can be added to as many groups as you want to be easy to manage, you could create groups like “enemies” or “collectables” for example, depending on your game. See add_to_group, is_in_group and remove_from_group. You can then retrieve all nodes in these groups, iterate them and even call methods on groups via the methods on SceneTree.
Networking with nodes: After connecting to a server (or making one, see ENetMultiplayerPeer), it is possible to use the built-in RPC (remote procedure call) system to communicate over the network. By calling rpc with a method name, it will be called locally and in all connected peers (peers = clients and the server that accepts connections). To identify which node receives the RPC call, Godot will use its NodePath (make sure node names are the same on all peers). Also, take a look at the high-level networking tutorial and corresponding demos.
Note: The script property is part of the Object class, not Node. It isn’t exposed like most properties but does have a setter and getter (see [method Object.set_script] and [method Object.get_script]).
Implementations
Sourceimpl Node
Manual extensions for the Node class.
impl Node
Manual extensions for the Node class.
Sourceimpl Node
impl Node
Sourcepub fn get_tree(&self) -> Gd<SceneTree>
pub fn get_tree(&self) -> Gd<SceneTree>
⚠️ Assuming the node is inside a scene tree, obtains the latter.
Panics
If the node is not inside the scene tree. If you’re unsure, use get_tree_or_null().
Sourcepub fn get_tree_or_null(&self) -> Option<Gd<SceneTree>>
pub fn get_tree_or_null(&self) -> Option<Gd<SceneTree>>
Fallibly obtains the scene tree containing the node, or None.
Sourceimpl Node
impl Node
pub fn print_orphan_nodes()
pub fn get_orphan_node_ids() -> Array<i64>
Sourcepub fn add_sibling(&mut self, sibling: impl AsArg<Gd<Node>>)
pub fn add_sibling(&mut self, sibling: impl AsArg<Gd<Node>>)
To set the default parameters, use Self::add_sibling_ex and its builder methods. See the book for detailed usage instructions.
pub fn add_sibling_ex<'ex>( &'ex mut self, sibling: impl AsArg<Gd<Node>> + 'ex, ) -> ExAddSibling<'ex>
pub fn set_name(&mut self, name: impl AsArg<StringName>)
pub fn get_name(&self) -> StringName
Sourcepub fn add_child(&mut self, node: impl AsArg<Gd<Node>>)
pub fn add_child(&mut self, node: impl AsArg<Gd<Node>>)
To set the default parameters, use Self::add_child_ex and its builder methods. See the book for detailed usage instructions.
pub fn add_child_ex<'ex>( &'ex mut self, node: impl AsArg<Gd<Node>> + 'ex, ) -> ExAddChild<'ex>
pub fn remove_child(&mut self, node: impl AsArg<Gd<Node>>)
Sourcepub fn reparent(&mut self, new_parent: impl AsArg<Gd<Node>>)
pub fn reparent(&mut self, new_parent: impl AsArg<Gd<Node>>)
To set the default parameters, use Self::reparent_ex and its builder methods. See the book for detailed usage instructions.
pub fn reparent_ex<'ex>( &'ex mut self, new_parent: impl AsArg<Gd<Node>> + 'ex, ) -> ExReparent<'ex>
Sourcepub fn get_child_count(&self) -> i32
pub fn get_child_count(&self) -> i32
To set the default parameters, use Self::get_child_count_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_child_count_ex<'ex>(&'ex self) -> ExGetChildCount<'ex>
Sourcepub fn get_children(&self) -> Array<Gd<Node>>
pub fn get_children(&self) -> Array<Gd<Node>>
To set the default parameters, use Self::get_children_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_children_ex<'ex>(&'ex self) -> ExGetChildren<'ex>
Sourcepub fn get_child(&self, idx: i32) -> Option<Gd<Node>>
pub fn get_child(&self, idx: i32) -> Option<Gd<Node>>
To set the default parameters, use Self::get_child_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_child_ex<'ex>(&'ex self, idx: i32) -> ExGetChild<'ex>
pub fn has_node(&self, path: impl AsArg<NodePath>) -> bool
pub fn get_node_or_null(&self, path: impl AsArg<NodePath>) -> Option<Gd<Node>>
pub fn get_parent(&self) -> Option<Gd<Node>>
Sourcepub fn find_child(&self, pattern: impl AsArg<GString>) -> Option<Gd<Node>>
pub fn find_child(&self, pattern: impl AsArg<GString>) -> Option<Gd<Node>>
To set the default parameters, use Self::find_child_ex and its builder methods. See the book for detailed usage instructions.
pub fn find_child_ex<'ex>( &'ex self, pattern: impl AsArg<GString> + 'ex, ) -> ExFindChild<'ex>
Sourcepub fn find_children(&self, pattern: impl AsArg<GString>) -> Array<Gd<Node>>
pub fn find_children(&self, pattern: impl AsArg<GString>) -> Array<Gd<Node>>
To set the default parameters, use Self::find_children_ex and its builder methods. See the book for detailed usage instructions.
pub fn find_children_ex<'ex>( &'ex self, pattern: impl AsArg<GString> + 'ex, ) -> ExFindChildren<'ex>
pub fn find_parent(&self, pattern: impl AsArg<GString>) -> Option<Gd<Node>>
pub fn has_node_and_resource(&self, path: impl AsArg<NodePath>) -> bool
pub fn get_node_and_resource( &self, path: impl AsArg<NodePath>, ) -> Array<Variant>
pub fn is_inside_tree(&self) -> bool
pub fn is_part_of_edited_scene(&self) -> bool
pub fn is_ancestor_of(&self, node: impl AsArg<Gd<Node>>) -> bool
pub fn is_greater_than(&self, node: impl AsArg<Gd<Node>>) -> bool
pub fn get_path(&self) -> NodePath
Sourcepub fn get_path_to(&self, node: impl AsArg<Gd<Node>>) -> NodePath
pub fn get_path_to(&self, node: impl AsArg<Gd<Node>>) -> NodePath
To set the default parameters, use Self::get_path_to_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_path_to_ex<'ex>( &'ex self, node: impl AsArg<Gd<Node>> + 'ex, ) -> ExGetPathTo<'ex>
Sourcepub fn add_to_group(&mut self, group: impl AsArg<StringName>)
pub fn add_to_group(&mut self, group: impl AsArg<StringName>)
To set the default parameters, use Self::add_to_group_ex and its builder methods. See the book for detailed usage instructions.
pub fn add_to_group_ex<'ex>( &'ex mut self, group: impl AsArg<StringName> + 'ex, ) -> ExAddToGroup<'ex>
pub fn remove_from_group(&mut self, group: impl AsArg<StringName>)
pub fn is_in_group(&self, group: impl AsArg<StringName>) -> bool
pub fn move_child(&mut self, child_node: impl AsArg<Gd<Node>>, to_index: i32)
pub fn get_groups(&self) -> Array<StringName>
pub fn set_owner(&mut self, owner: impl AsArg<Option<Gd<Node>>>)
pub fn get_owner(&self) -> Option<Gd<Node>>
Sourcepub fn get_index(&self) -> i32
pub fn get_index(&self) -> i32
To set the default parameters, use Self::get_index_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_index_ex<'ex>(&'ex self) -> ExGetIndex<'ex>
pub fn print_tree(&mut self)
pub fn print_tree_pretty(&mut self)
pub fn get_tree_string(&self) -> GString
pub fn get_tree_string_pretty(&self) -> GString
pub fn set_scene_file_path(&mut self, scene_file_path: impl AsArg<GString>)
pub fn get_scene_file_path(&self) -> GString
pub fn propagate_notification(&mut self, what: i32)
Sourcepub fn propagate_call(&mut self, method: impl AsArg<StringName>)
pub fn propagate_call(&mut self, method: impl AsArg<StringName>)
To set the default parameters, use Self::propagate_call_ex and its builder methods. See the book for detailed usage instructions.
pub fn propagate_call_ex<'ex>( &'ex mut self, method: impl AsArg<StringName> + 'ex, ) -> ExPropagateCall<'ex>
pub fn set_physics_process(&mut self, enable: bool)
pub fn get_physics_process_delta_time(&self) -> f64
pub fn is_physics_processing(&self) -> bool
pub fn get_process_delta_time(&self) -> f64
pub fn set_process(&mut self, enable: bool)
pub fn set_process_priority(&mut self, priority: i32)
pub fn get_process_priority(&self) -> i32
pub fn set_physics_process_priority(&mut self, priority: i32)
pub fn get_physics_process_priority(&self) -> i32
pub fn is_processing(&self) -> bool
pub fn set_process_input(&mut self, enable: bool)
pub fn is_processing_input(&self) -> bool
pub fn set_process_shortcut_input(&mut self, enable: bool)
pub fn is_processing_shortcut_input(&self) -> bool
pub fn set_process_unhandled_input(&mut self, enable: bool)
pub fn is_processing_unhandled_input(&self) -> bool
pub fn set_process_unhandled_key_input(&mut self, enable: bool)
pub fn is_processing_unhandled_key_input(&self) -> bool
pub fn set_process_mode(&mut self, mode: ProcessMode)
pub fn get_process_mode(&self) -> ProcessMode
pub fn can_process(&self) -> bool
pub fn set_process_thread_group(&mut self, mode: ProcessThreadGroup)
pub fn get_process_thread_group(&self) -> ProcessThreadGroup
pub fn set_process_thread_messages(&mut self, flags: ProcessThreadMessages)
pub fn get_process_thread_messages(&self) -> ProcessThreadMessages
pub fn set_process_thread_group_order(&mut self, order: i32)
pub fn get_process_thread_group_order(&self) -> i32
pub fn queue_accessibility_update(&mut self)
pub fn get_accessibility_element(&self) -> Rid
pub fn set_display_folded(&mut self, fold: bool)
pub fn is_displayed_folded(&self) -> bool
pub fn set_process_internal(&mut self, enable: bool)
pub fn is_processing_internal(&self) -> bool
pub fn set_physics_process_internal(&mut self, enable: bool)
pub fn is_physics_processing_internal(&self) -> bool
pub fn set_physics_interpolation_mode(&mut self, mode: PhysicsInterpolationMode)
pub fn get_physics_interpolation_mode(&self) -> PhysicsInterpolationMode
pub fn is_physics_interpolated(&self) -> bool
pub fn is_physics_interpolated_and_enabled(&self) -> bool
pub fn reset_physics_interpolation(&mut self)
pub fn set_auto_translate_mode(&mut self, mode: AutoTranslateMode)
pub fn get_auto_translate_mode(&self) -> AutoTranslateMode
pub fn can_auto_translate(&self) -> bool
pub fn set_translation_domain_inherited(&mut self)
pub fn get_window(&self) -> Option<Gd<Window>>
pub fn get_last_exclusive_window(&self) -> Option<Gd<Window>>
pub fn create_tween(&mut self) -> Gd<Tween>
Sourcepub fn duplicate(&self) -> Option<Gd<Node>>
👎Deprecated: Use Gd::duplicate_node() or Gd::duplicate_node_ex().
pub fn duplicate(&self) -> Option<Gd<Node>>
Use Gd::duplicate_node() or Gd::duplicate_node_ex().
To set the default parameters, use Self::duplicate_ex and its builder methods. See the book for detailed usage instructions.
pub fn duplicate_ex<'ex>(&'ex self) -> ExDuplicate<'ex>
Use Gd::duplicate_node() or Gd::duplicate_node_ex().
Sourcepub fn replace_by(&mut self, node: impl AsArg<Gd<Node>>)
pub fn replace_by(&mut self, node: impl AsArg<Gd<Node>>)
To set the default parameters, use Self::replace_by_ex and its builder methods. See the book for detailed usage instructions.
pub fn replace_by_ex<'ex>( &'ex mut self, node: impl AsArg<Gd<Node>> + 'ex, ) -> ExReplaceBy<'ex>
pub fn set_scene_instance_load_placeholder(&mut self, load_placeholder: bool)
pub fn get_scene_instance_load_placeholder(&self) -> bool
pub fn set_editable_instance( &mut self, node: impl AsArg<Gd<Node>>, is_editable: bool, )
pub fn is_editable_instance(&self, node: impl AsArg<Option<Gd<Node>>>) -> bool
pub fn get_viewport(&self) -> Option<Gd<Viewport>>
pub fn queue_free(&mut self)
pub fn request_ready(&mut self)
pub fn is_node_ready(&self) -> bool
To set the default parameters, use Self::set_multiplayer_authority_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_multiplayer(&self) -> Option<Gd<MultiplayerApi>>
pub fn rpc_config(&mut self, method: impl AsArg<StringName>, config: &Variant)
pub fn get_node_rpc_config(&self) -> Variant
pub fn set_editor_description( &mut self, editor_description: impl AsArg<GString>, )
pub fn get_editor_description(&self) -> GString
pub fn set_unique_name_in_owner(&mut self, enable: bool)
pub fn is_unique_name_in_owner(&self) -> bool
Sourcepub fn atr(&self, message: impl AsArg<GString>) -> GString
pub fn atr(&self, message: impl AsArg<GString>) -> GString
To set the default parameters, use Self::atr_ex and its builder methods. See the book for detailed usage instructions.
pub fn atr_ex<'ex>(&'ex self, message: impl AsArg<GString> + 'ex) -> ExAtr<'ex>
Sourcepub fn atr_n(
&self,
message: impl AsArg<GString>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn atr_n( &self, message: impl AsArg<GString>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use Self::atr_n_ex and its builder methods. See the book for detailed usage instructions.
pub fn atr_n_ex<'ex>( &'ex self, message: impl AsArg<GString> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExAtrN<'ex>
Sourcepub fn rpc(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn rpc( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_rpc(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_rpc( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
Sourcepub fn rpc_id(
&mut self,
peer_id: i64,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn rpc_id( &mut self, peer_id: i64, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_rpc_id(
&mut self,
peer_id: i64,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_rpc_id( &mut self, peer_id: i64, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn update_configuration_warnings(&mut self)
Sourcepub fn call_deferred_thread_group(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred_thread_group( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_call_deferred_thread_group(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred_thread_group( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred_thread_group( &mut self, property: impl AsArg<StringName>, value: &Variant, )
pub fn notify_deferred_thread_group(&mut self, what: i32)
Sourcepub fn call_thread_safe(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_thread_safe( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_call_thread_safe(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_thread_safe( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_thread_safe( &mut self, property: impl AsArg<StringName>, value: &Variant, )
pub fn notify_thread_safe(&mut self, what: i32)
Sourcepub fn notify(&mut self, what: NodeNotification)
pub fn notify(&mut self, what: NodeNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
Sourcepub fn notify_reversed(&mut self, what: NodeNotification)
pub fn notify_reversed(&mut self, what: NodeNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
pub fn get_class(&self) -> GString
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Sourcepub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use Self::get_meta_ex and its builder methods. See the book for detailed usage instructions.
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn get_meta_list(&self) -> Array<StringName>
Sourcepub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use Self::add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Sourcepub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
Sourcepub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
Sourcepub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn set_block_signals(&mut self, enable: bool)
pub fn is_blocking_signals(&self) -> bool
pub fn notify_property_list_changed(&mut self)
pub fn set_message_translation(&mut self, enable: bool)
pub fn can_translate_messages(&self) -> bool
Sourcepub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use Self::tr_ex and its builder methods. See the book for detailed usage instructions.
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Sourcepub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use Self::tr_n_ex and its builder methods. See the book for detailed usage instructions.
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
pub fn get_translation_domain(&self) -> StringName
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn is_queued_for_deletion(&self) -> bool
pub fn cancel_free(&mut self)
Sourcepub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
Sourcepub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.